==> analytics-2.3.0816.1-sources.jar: com/zing/zalo/devicetrackingsdk/a.java <==
package com.zing.zalo.devicetrackingsdk;

import android.accounts.Account;
import android.accounts.AccountManager;
import android.content.Context;
import android.os.Handler;
import android.os.Handler.Callback;
import android.os.HandlerThread;
import android.os.Message;
import android.text.TextUtils;
import com.zing.zalo.zalosdk.common.UtilsCore;
import com.zing.zalo.zalosdk.core.helper.Utils;
import com.zing.zalo.zalosdk.core.http.HttpClientRequest;
import com.zing.zalo.zalosdk.core.http.HttpClientRequest.Type;
import com.zing.zalo.zalosdk.core.log.Log;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Timer;
import java.util.TimerTask;
import org.json.JSONArray;
import org.json.JSONObject;

public class a implements Callback, com.zing.zalo.devicetrackingsdk.a.a {
    public static int a = 1000;
    public static long b = 120000;
    public static long c = 60000;
    private static boolean s = false;
    Context d;
    String e;
    private BaseAppInfo f;
    private BaseAppInfoStorage g;
    private com.zing.zalo.devicetrackingsdk.c.a h;
    private int i = 1000;
    private long j = 120000;
    private long k = 60000;
    private long l = 100;
    private HandlerThread m = new HandlerThread("zdt-event-tracker", 1);
    private Handler n;
    private Timer o;
    private Timer p;
    private boolean q;
    private JSONArray r;

    public a(Context context, BaseAppInfoStorage baseAppInfoStorage, com.zing.zalo.devicetrackingsdk.c.a aVar, BaseAppInfo baseAppInfo, String str) {
        this.m.start();
        this.n = new Handler(this.m.getLooper(), this);
        Log.v("init event tracker");
        this.d = context;
        this.g = baseAppInfoStorage;
        this.h = aVar;
        this.f = baseAppInfo;
        this.e = str;
        this.r = new JSONArray();
        Message message = new Message();
        message.what = 20484;
        this.n.sendMessage(message);
        if (this.j > 0) {
            d();
        }
        if (this.k > 0) {
            f();
        }
        Log.v("start zdt-event-tracker thread");
    }

    private com.zing.zalo.devicetrackingsdk.b.a a(String str, String str2, long j, Map<String, String> map) {
        Map hashMap;
        if (map == null) {
            hashMap = new HashMap();
        }
        if (!(str2 == null || hashMap.containsKey("name"))) {
            hashMap.put("name", str2);
        }
        return new com.zing.zalo.devicetrackingsdk.b.a(str, j, Utils.mapToJSONObject(hashMap));
    }

    private void b(com.zing.zalo.devicetrackingsdk.b.a aVar) {
        if (this.q) {
            this.h.a(aVar);
            j();
            List b = this.h.b();
            if (b != null && ((long) b.size()) >= this.l) {
                new Thread(new Runnable(this) {
                    final /* synthetic */ a a;

                    {
                        this.a = r1;
                    }

                    public void run() {
                        this.a.a();
                    }
                }).start();
            }
        }
    }

    private void c() {
        if (this.o != null) {
            Log.v("cancel dispatch timer");
            this.o.cancel();
            this.o = null;
        }
    }

    private void d() {
        Log.v("schedule dispatch timer");
        c();
        try {
            this.o = new Timer();
            this.o.scheduleAtFixedRate(new TimerTask(this) {
                final /* synthetic */ a a;

                {
                    this.a = r1;
                }

                public void run() {
                    this.a.a();
                }
            }, this.j, this.j);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private void e() {
        if (this.p != null) {
            Log.v("cancel store events timer");
            this.p.cancel();
            this.p = null;
        }
    }

    private void f() {
        Log.v("schedule store events timer");
        e();
        try {
            this.p = new Timer();
            this.p.scheduleAtFixedRate(new TimerTask(this) {
                final /* synthetic */ a a;

                {
                    this.a = r1;
                }

                public void run() {
                    this.a.b();
                }
            }, this.k, this.k);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private void g() {
        try {
            if (Utils.isPerMissionGranted(this.d, "android.permission.GET_ACCOUNTS")) {
                Account[] accountsByType = AccountManager.get(this.d).getAccountsByType("com.google");
                if (accountsByType.length > 0) {
                    String str = accountsByType[0].name;
                    JSONObject jSONObject = new JSONObject();
                    jSONObject.put("socialId", str);
                    jSONObject.put("social", "google");
                    for (int i = 0; i < this.r.length(); i++) {
                        if (this.r.getJSONObject(i).getString("social").equals("google")) {
                            this.r = UtilsCore.remove(i, this.r);
                            break;
                        }
                    }
                    this.r.put(jSONObject);
                }
            }
        } catch (Exception e) {
        }
    }

    private void h() {
        try {
            if (this.h.b().size() != 0 && this.q) {
                Object obj;
                Message message = new Message();
                message.what = 20485;
                this.n.sendMessage(message);
                JSONArray jSONArray = new JSONArray();
                JSONObject l = l();
                String deviceId = this.f.getDeviceId();
                String sDKId = this.f.getSDKId();
                String privateKey = this.f.getPrivateKey();
                String str = deviceId == null ? "" : deviceId;
                if (sDKId == null) {
                    obj = "";
                } else {
                    String str2 = sDKId;
                }
                String str3 = TextUtils.isEmpty(obj) ? "0" : "1";
                String an = this.f.getAn();
                String av = this.f.getAv();
                String str4 = this.e;
                sDKId = this.g.getOAuthCode();
                String str5 = sDKId == null ? "" : sDKId;
                String str6 = "" + new Date().getTime();
                String jSONObject = l.toString();
                String jSONArray2 = jSONArray.toString();
                String jSONArray3 = this.r.toString();
                String[] strArr = new String[]{"pl", "appId", "oauthCode", "data", "apps", "ts", "zdId", "an", "av", "et", "gzip", "socialAcc"};
                String[] strArr2 = new String[]{"android", str4, str5, jSONObject, jSONArray2, str6, str, an, av, str3, "0", jSONArray3};
                deviceId = s ? "http://dev.centralize.zaloapp.com/appsv2/mobile/android" : "https://centralized.zaloapp.com/apps/mobile/android";
                Log.i("debuglog", "submit event: strEventData: " + jSONObject);
                Log.i("debuglog", "submit event: strAppData: " + jSONArray2);
                Log.i("debuglog", "submit event: strSocialAcc: " + jSONArray3);
                Log.i("debuglog", "submit event: url: " + deviceId);
                HttpClientRequest httpClientRequest = new HttpClientRequest(Type.POST, deviceId);
                JSONObject jSONObject2 = null;
                if (str3.equals("0")) {
                    sDKId = Utils.getSignature("https://centralized.zaloapp.com", "/apps/mobile/android", strArr, strArr2, "@#centralize#@");
                    if (s) {
                        sDKId = Utils.getSignature("http://dev.centralize.zaloapp.com", "/appsv2/mobile/android", strArr, strArr2, "@#centralize#@");
                    }
                    httpClientRequest.addParams("pl", "android");
                    httpClientRequest.addParams("appId", str4);
                    httpClientRequest.addParams("oauthCode", str5);
                    httpClientRequest.addParams("zdId", str);
                    httpClientRequest.addParams("data", jSONObject);
                    httpClientRequest.addParams("apps", jSONArray2);
                    httpClientRequest.addParams("ts", str6);
                    httpClientRequest.addParams("sig", sDKId);
                    httpClientRequest.addParams("an", an);
                    httpClientRequest.addParams("av", av);
                    httpClientRequest.addParams("gzip", "0");
                    httpClientRequest.addParams("et", "0");
                    httpClientRequest.addParams("socialAcc", jSONArray3);
                    jSONObject2 = httpClientRequest.getJSON();
                } else {
                    JSONObject jSONObject3 = new JSONObject();
                    jSONObject3.put("pl", "android");
                    jSONObject3.put("appId", str4);
                    jSONObject3.put("oauthCode", str5);
                    jSONObject3.put("zdId", str);
                    jSONObject3.put("data", jSONObject);
                    jSONObject3.put("apps", jSONArray2);
                    jSONObject3.put("an", an);
                    jSONObject3.put("av", av);
                    jSONObject3.put("socialAcc", jSONArray3);
                    deviceId = UtilsCore.postFile(deviceId + "?et=1&sdkId=" + obj + "&gzip=0", "data.dat", "zce", UtilsCore.encrypt(privateKey, jSONObject3.toString()), null);
                    if (deviceId != null) {
                        jSONObject2 = new JSONObject(deviceId);
                    }
                }
                if (jSONObject2 != null) {
                    Log.i("debuglog", "submit event response: " + jSONObject2.toString());
                    if (jSONObject2.getInt("error") == 0) {
                        this.h.c();
                    }
                }
            }
        } catch (Exception e) {
            Log.e(e);
        }
    }

    private void i() {
        if (this.q) {
            this.h.d();
        }
    }

    private void j() {
        int i = 0;
        if (this.q) {
            List b = this.h.b();
            if (b.size() > this.i) {
                Log.v("ZDK", "exceed max number of events %d > %d", new Object[]{Integer.valueOf(b.size()), Integer.valueOf(this.i)});
                com.zing.zalo.devicetrackingsdk.b.a[] aVarArr = (com.zing.zalo.devicetrackingsdk.b.a[]) b.subList(0, b.size() - this.i).toArray(new com.zing.zalo.devicetrackingsdk.b.a[0]);
                while (i < aVarArr.length) {
                    this.h.b(aVarArr[i]);
                    i++;
                }
            }
        }
    }

    private void k() {
        this.h.a();
        this.q = true;
    }

    private JSONObject l() {
        JSONObject jSONObject = new JSONObject();
        JSONObject prepareTrackingData = this.f.prepareTrackingData();
        JSONArray jSONArray = new JSONArray();
        try {
            for (com.zing.zalo.devicetrackingsdk.b.a aVar : this.h.b()) {
                JSONObject jSONObject2 = new JSONObject();
                JSONObject c = aVar.c();
                if (c.has("name")) {
                    jSONObject2.put("name", c.get("name"));
                }
                jSONObject2.put("extras", c);
                jSONObject2.put("act", aVar.a());
                jSONObject2.put("ts", aVar.b());
                jSONArray.put(jSONObject2);
            }
            jSONObject.put("evt", jSONArray);
            jSONObject.put("dat", prepareTrackingData);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return jSONObject;
    }

    public void a() {
        Message message = new Message();
        message.what = 20480;
        this.n.sendMessage(message);
    }

    public void a(int i) {
        this.i = i;
    }

    public void a(long j) {
        if (j > 0 || this.o == null) {
            if (j < 10000) {
                j = 10000;
            }
            this.j = j;
            d();
            return;
        }
        c();
    }

    public synchronized void a(com.zing.zalo.devicetrackingsdk.b.a aVar) {
        if (this.q) {
            this.h.a(aVar);
            this.h.d();
        }
    }

    public void a(String str, long j, Map<String, String> map) {
        com.zing.zalo.devicetrackingsdk.b.a a = a(str, null, j, map);
        Message message = new Message();
        message.what = 20481;
        message.obj = a;
        this.n.sendMessage(message);
    }

    public void b() {
        Message message = new Message();
        message.what = 20482;
        this.n.sendMessage(message);
    }

    public void b(long j) {
        if (j <= 0) {
            e();
            return;
        }
        if (j < 10000) {
            j = 10000;
        }
        this.k = j;
        f();
    }

    public boolean handleMessage(Message message) {
        switch (message.what) {
            case 20480:
                h();
                break;
            case 20481:
                b((com.zing.zalo.devicetrackingsdk.b.a) message.obj);
                break;
            case 20482:
                i();
                break;
            case 20484:
                k();
                break;
            case 20485:
                g();
                break;
            default:
                return false;
        }
        return true;
    }
}

==> analytics-2.3.0816.7-sources.jar: com/zing/zalo/devicetrackingsdk/a.java <==
package com.zing.zalo.devicetrackingsdk;

import android.accounts.Account;
import android.accounts.AccountManager;
import android.content.Context;
import android.os.Handler;
import android.os.Handler.Callback;
import android.os.HandlerThread;
import android.os.Message;
import android.text.TextUtils;
import com.zing.zalo.zalosdk.analytics.internal.b;
import com.zing.zalo.zalosdk.analytics.internal.e;
import com.zing.zalo.zalosdk.common.UtilsCore;
import com.zing.zalo.zalosdk.core.helper.Utils;
import com.zing.zalo.zalosdk.core.http.HttpClientRequest;
import com.zing.zalo.zalosdk.core.http.HttpClientRequest.Type;
import com.zing.zalo.zalosdk.core.log.Log;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Timer;
import java.util.TimerTask;
import org.json.JSONArray;
import org.json.JSONObject;

public class a implements Callback, com.zing.zalo.zalosdk.analytics.internal.a {
    public static int a = 1000;
    public static long b = 120000;
    public static long c = 60000;
    private static boolean s = false;
    Context d;
    String e;
    private BaseAppInfo f;
    private BaseAppInfoStorage g;
    private e h;
    private int i = 1000;
    private long j = 120000;
    private long k = 60000;
    private long l = 100;
    private HandlerThread m = new HandlerThread("zdt-event-tracker", 1);
    private Handler n;
    private Timer o;
    private Timer p;
    private boolean q;
    private JSONArray r;

    public a(Context context, BaseAppInfoStorage baseAppInfoStorage, e eVar, BaseAppInfo baseAppInfo, String str) {
        this.m.start();
        this.n = new Handler(this.m.getLooper(), this);
        Log.v("init event tracker");
        this.d = context;
        this.g = baseAppInfoStorage;
        this.h = eVar;
        this.f = baseAppInfo;
        this.e = str;
        this.r = new JSONArray();
        Message message = new Message();
        message.what = 20484;
        this.n.sendMessage(message);
        if (this.j > 0) {
            d();
        }
        if (this.k > 0) {
            f();
        }
        Log.v("start zdt-event-tracker thread");
    }

    private b a(String str, String str2, long j, Map<String, String> map) {
        Map hashMap;
        if (map == null) {
            hashMap = new HashMap();
        }
        if (!(str2 == null || hashMap.containsKey("name"))) {
            hashMap.put("name", str2);
        }
        return new b(str, j, Utils.mapToJSONObject(hashMap));
    }

    private void b(b bVar) {
        if (this.q) {
            this.h.a(bVar);
            j();
            List b = this.h.b();
            if (b != null && ((long) b.size()) >= this.l) {
                new Thread(new Runnable(this) {
                    final /* synthetic */ a a;

                    {
                        this.a = r1;
                    }

                    public void run() {
                        this.a.a();
                    }
                }).start();
            }
        }
    }

    private void c() {
        if (this.o != null) {
            Log.v("cancel dispatch timer");
            this.o.cancel();
            this.o = null;
        }
    }

    private void d() {
        Log.v("schedule dispatch timer");
        c();
        try {
            this.o = new Timer();
            this.o.scheduleAtFixedRate(new TimerTask(this) {
                final /* synthetic */ a a;

                {
                    this.a = r1;
                }

                public void run() {
                    this.a.a();
                }
            }, this.j, this.j);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private void e() {
        if (this.p != null) {
            Log.v("cancel store events timer");
            this.p.cancel();
            this.p = null;
        }
    }

    private void f() {
        Log.v("schedule store events timer");
        e();
        try {
            this.p = new Timer();
            this.p.scheduleAtFixedRate(new TimerTask(this) {
                final /* synthetic */ a a;

                {
                    this.a = r1;
                }

                public void run() {
                    this.a.b();
                }
            }, this.k, this.k);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private void g() {
        try {
            if (Utils.isPerMissionGranted(this.d, "android.permission.GET_ACCOUNTS")) {
                Account[] accountsByType = AccountManager.get(this.d).getAccountsByType("com.google");
                if (accountsByType.length > 0) {
                    String str = accountsByType[0].name;
                    JSONObject jSONObject = new JSONObject();
                    jSONObject.put("socialId", str);
                    jSONObject.put("social", "google");
                    for (int i = 0; i < this.r.length(); i++) {
                        if (this.r.getJSONObject(i).getString("social").equals("google")) {
                            this.r = UtilsCore.remove(i, this.r);
                            break;
                        }
                    }
                    this.r.put(jSONObject);
                }
            }
        } catch (Exception e) {
        }
    }

    private void h() {
        try {
            if (this.h.b().size() != 0 && this.q) {
                Object obj;
                Message message = new Message();
                message.what = 20485;
                this.n.sendMessage(message);
                JSONArray jSONArray = new JSONArray();
                JSONObject l = l();
                String deviceId = this.f.getDeviceId();
                String sDKId = this.f.getSDKId();
                String privateKey = this.f.getPrivateKey();
                String str = deviceId == null ? "" : deviceId;
                if (sDKId == null) {
                    obj = "";
                } else {
                    String str2 = sDKId;
                }
                String str3 = TextUtils.isEmpty(obj) ? "0" : "1";
                String an = this.f.getAn();
                String av = this.f.getAv();
                String str4 = this.e;
                sDKId = this.g.getOAuthCode();
                String str5 = sDKId == null ? "" : sDKId;
                String str6 = "" + new Date().getTime();
                String jSONObject = l.toString();
                String jSONArray2 = jSONArray.toString();
                String jSONArray3 = this.r.toString();
                String[] strArr = new String[]{"pl", "appId", "oauthCode", "data", "apps", "ts", "zdId", "an", "av", "et", "gzip", "socialAcc"};
                String[] strArr2 = new String[]{"android", str4, str5, jSONObject, jSONArray2, str6, str, an, av, str3, "0", jSONArray3};
                deviceId = s ? "http://dev.centralize.zaloapp.com/appsv2/mobile/android" : "https://centralized.zaloapp.com/apps/mobile/android";
                Log.i("debuglog", "submit event: strEventData: " + jSONObject);
                Log.i("debuglog", "submit event: strAppData: " + jSONArray2);
                Log.i("debuglog", "submit event: strSocialAcc: " + jSONArray3);
                Log.i("debuglog", "submit event: url: " + deviceId);
                HttpClientRequest httpClientRequest = new HttpClientRequest(Type.POST, deviceId);
                JSONObject jSONObject2 = null;
                if (str3.equals("0")) {
                    sDKId = Utils.getSignature("https://centralized.zaloapp.com", "/apps/mobile/android", strArr, strArr2, "@#centralize#@");
                    if (s) {
                        sDKId = Utils.getSignature("http://dev.centralize.zaloapp.com", "/appsv2/mobile/android", strArr, strArr2, "@#centralize#@");
                    }
                    httpClientRequest.addParams("pl", "android");
                    httpClientRequest.addParams("appId", str4);
                    httpClientRequest.addParams("oauthCode", str5);
                    httpClientRequest.addParams("zdId", str);
                    httpClientRequest.addParams("data", jSONObject);
                    httpClientRequest.addParams("apps", jSONArray2);
                    httpClientRequest.addParams("ts", str6);
                    httpClientRequest.addParams("sig", sDKId);
                    httpClientRequest.addParams("an", an);
                    httpClientRequest.addParams("av", av);
                    httpClientRequest.addParams("gzip", "0");
                    httpClientRequest.addParams("et", "0");
                    httpClientRequest.addParams("socialAcc", jSONArray3);
                    jSONObject2 = httpClientRequest.getJSON();
                } else {
                    JSONObject jSONObject3 = new JSONObject();
                    jSONObject3.put("pl", "android");
                    jSONObject3.put("appId", str4);
                    jSONObject3.put("oauthCode", str5);
                    jSONObject3.put("zdId", str);
                    jSONObject3.put("data", jSONObject);
                    jSONObject3.put("apps", jSONArray2);
                    jSONObject3.put("an", an);
                    jSONObject3.put("av", av);
                    jSONObject3.put("socialAcc", jSONArray3);
                    deviceId = UtilsCore.postFile(deviceId + "?et=1&sdkId=" + obj + "&gzip=0", "data.dat", "zce", UtilsCore.encrypt(privateKey, jSONObject3.toString()), null);
                    if (deviceId != null) {
                        jSONObject2 = new JSONObject(deviceId);
                    }
                }
                if (jSONObject2 != null) {
                    Log.i("debuglog", "submit event response: " + jSONObject2.toString());
                    if (jSONObject2.getInt("error") == 0) {
                        this.h.c();
                    }
                }
            }
        } catch (Exception e) {
            Log.e(e);
        }
    }

    private void i() {
        if (this.q) {
            this.h.d();
        }
    }

    private void j() {
        int i = 0;
        if (this.q) {
            List b = this.h.b();
            if (b.size() > this.i) {
                Log.v("ZDK", "exceed max number of events %d > %d", new Object[]{Integer.valueOf(b.size()), Integer.valueOf(this.i)});
                b[] bVarArr = (b[]) b.subList(0, b.size() - this.i).toArray(new b[0]);
                while (i < bVarArr.length) {
                    this.h.b(bVarArr[i]);
                    i++;
                }
            }
        }
    }

    private void k() {
        this.h.a();
        this.q = true;
    }

    private JSONObject l() {
        JSONObject jSONObject = new JSONObject();
        JSONObject prepareTrackingData = this.f.prepareTrackingData();
        JSONArray jSONArray = new JSONArray();
        try {
            for (b bVar : this.h.b()) {
                JSONObject jSONObject2 = new JSONObject();
                JSONObject c = bVar.c();
                if (c.has("name")) {
                    jSONObject2.put("name", c.get("name"));
                }
                jSONObject2.put("extras", c);
                jSONObject2.put("act", bVar.a());
                jSONObject2.put("ts", bVar.b());
                jSONArray.put(jSONObject2);
            }
            jSONObject.put("evt", jSONArray);
            jSONObject.put("dat", prepareTrackingData);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return jSONObject;
    }

    public void a() {
        Message message = new Message();
        message.what = 20480;
        this.n.sendMessage(message);
    }

    public void a(int i) {
        this.i = i;
    }

    public void a(long j) {
        if (j > 0 || this.o == null) {
            if (j < 10000) {
                j = 10000;
            }
            this.j = j;
            d();
            return;
        }
        c();
    }

    public synchronized void a(b bVar) {
        if (this.q) {
            this.h.a(bVar);
            this.h.d();
        }
    }

    public void a(String str, long j, Map<String, String> map) {
        b a = a(str, null, j, map);
        Message message = new Message();
        message.what = 20481;
        message.obj = a;
        this.n.sendMessage(message);
    }

    public void b() {
        Message message = new Message();
        message.what = 20482;
        this.n.sendMessage(message);
    }

    public void b(long j) {
        if (j <= 0) {
            e();
            return;
        }
        if (j < 10000) {
            j = 10000;
        }
        this.k = j;
        f();
    }

    public boolean handleMessage(Message message) {
        switch (message.what) {
            case 20480:
                h();
                break;
            case 20481:
                b((b) message.obj);
                break;
            case 20482:
                i();
                break;
            case 20484:
                k();
                break;
            case 20485:
                g();
                break;
            default:
                return false;
        }
        return true;
    }
}
